
************************************************************************************
************************************************************************************

version 15
set more off, perm 
clear all

capture log close 

************************************************************************************
************************************************************************************

set seed 123454321

************************************************************************************
************************************************************************************

* =========================================
* Global Macros for Paths
* =========================================

global drive 		"C:"											// Network Letter
global workingDir	"${drive}/VanWinkle_Leopold_2021_Replication"	// Path
global data			"${workingDir}/01_data"							// Data
	global temp 		"${data}/01_temp" 							// Temporary Data 
	global cnef 		"${data}/02_cnef" 							// CNEF Data 	
	global bhps 		"${data}/03_bhps" 							// BHPS Data 
global dofiles 		"${workingDir}/02_do-files"						// do-files
global logs			"${workingDir}/03_logs"							// log-files
global graphs 		"${workingDir}/04_graphs" 						// graphs
global tables 		"${workingDir}/05_tables" 						// tabels

************************************************************************************
************************************************************************************

set maxvar 15000, perm
set matsize 11000, perm

************************************************************************************
************************************************************************************

* =========================================
* Execute Do-Files
* =========================================

do "$dofiles/01_00_BHPS_edu.do"				// Years of education for BHPS
do "$dofiles/01_01_cnef_prep.do"			// Rename CNEF variables
do "$dofiles/02_variables_prep.do"			// Prepare CNEF analysis dataset
do "$dofiles/03_descriptives.do"			// Descriptive tables and figures
do "$dofiles/04_1_unadjusted_analyses.do" 	// PSID unadjusted regression outputs
do "$dofiles/04_2_adjusted_analyses.do"		// PSID adjusted regression outputs
do "$dofiles/05_country_analyses.do"		// CNEF regression outputs
do "$dofiles/06_additional_analyses.do"		// Robustness analyses
do "$dofiles/07_cohabitation_analyses.do"	// Analyses with cohabitation

************************************************************************************
************************************************************************************

exit

************************************************************************************
************************************************************************************
