
/*
This file creates a person-year dataset from waves 1-17 of the BHPS that 
includes a person identifer (pid), wave identifer (year), age left school
(scend), highest qualification (qfedhi), and the fewest years of education
theoretically assocaiated with the highest qualification as defined by the
ISCED-97 scheme. Years of education include university and vocational 
education, similar to the DIW years of education variable in the SOEP.
*/

*** WAVE 1 AQFEDHI ***
use pid ascend aqfedhi using "$bhps/bhps_w1\aindresp.dta", clear

* 1		Higher Degree (e.g. MA)					17
* 2		First Degree (e.g. BA)					16
* 3		Teaching QF								15
* 4 	Other Higher QF							15
* 5 	Nursing QF								15
* 6		GCE A Levels							13
* 7 	GCE O-Levels							11
* 8 	Commercial QF, No O-Levels (NVQ1)		11
* 9 	CSE Grade 2-5 (e.g., Old O-Levels)		11
* 10	Apprenticeship (e.g. Mas)				14
* 11	Other QF (equiv. to O-Levels)			11
* 12	No QF - Set to School Leving Age - 5	(ascend - 5)
* 13	Still in School							.

gen eduyrs = ascend - 5 if ascend>0 & aqfedhi==12
	replace eduyrs = 17 if aqfedhi==1
	replace eduyrs = 16 if aqfedhi==2
	replace eduyrs = 15 														///
		if aqfedhi==3 | aqfedhi==4 | aqfedhi==5
	replace eduyrs = 13 if aqfedhi==6
	replace eduyrs = 11 														///
		if aqfedhi==7 | aqfedhi==8 | aqfedhi==9 | aqfedhi==11
	replace eduyrs = 14 if aqfedhi==10
	replace eduyrs = . if aqfedhi==13
	
gen year = 1991
gen scend = ascend
	cap drop ascend
gen qfedhi = aqfedhi
	cap drop aqfedhi

*** WAVES 2 - 17 (Automated) ***
local y = 1992
local z = 2
foreach a in b c d e f g h i j k l m n o p q r {

	global wave "$bhps/bhps_w`z'"
append using "$wave/`a'indresp.dta", keep(pid `a'scend `a'qfedhi) gen(add)
	replace scend = `a'scend if add==1
		cap drop `a'scend
	replace qfedhi = `a'qfedhi if add==1
		cap drop `a'qfedhi

replace year = `y' if add==1
bys pid (year): replace scend = scend[_n-1] 									///
	if scend==-8 & scend[_n-1]>0 & add==1

replace eduyrs = scend - 5 if scend>0 & qfedhi==12 & add==1
	replace eduyrs = 17 if qfedhi==1 & add==1
	replace eduyrs = 16 if qfedhi==2 & add==1
	replace eduyrs = 15 														///
		if (qfedhi==3 | qfedhi==4 | qfedhi==5) & add==1
	replace eduyrs = 13 if qfedhi==6 & add==1
	replace eduyrs = 11 														///
		if (qfedhi==7 | qfedhi==8 | qfedhi==9 | qfedhi==11) & add==1
	replace eduyrs = 14 if qfedhi==10 & add==1
	replace eduyrs = . if qfedhi==13 & add==1
	
cap drop add	
local y = `y' + 1
local z = `z' + 1
}

* Pull Down Information from Previous Year(s) if Interview was Proxy
bys pid (year): replace eduyrs = eduyrs[_n-1] 									///
	if eduyrs==. & eduyrs[_n-1]!=. & qfedhi==-7

*** Save Education File to be Merged with CNEF Data ***
save "$temp/BHPS_eduyrs.dta", replace	
	
	
