
*** This Do-File Creates Harmonized Data Files from the CNEF files ***

*-----------------------------------------------------------------------------*
*  GENERATE SOEP DATASET              		                                  *
*-----------------------------------------------------------------------------*

use "$cnef/gequiv_long.dta", clear

keep 	x11101ll 	///	Person ID
		year		///
		d11102ll 	/// Gender
		x11102 		/// Household ID
		x11104ll	/// Subsample Indicator
		d11101 		/// Age
		d11104		/// Marital Status
		d11105		/// Relationship to HH Head
		d11106 		/// Number of Persons in HH
		d11107 		/// Number of Children in HH
		d11109 		/// Years of Education
		e11101 		/// Annual Work Hours
		e11102 		/// Employment Status
		i11101 		/// HH Pre-Government Transfers
		i11102 		/// HH POst-Government Transfers
		i11110		/// Individual Labor Market Income
		w11101 		/// Cross-sectional Weight
		w11102 		/// HH Weight
		w11103		/// Longitudinal Weight
		h11103 		/// Number of HH Members 0-1 
		h11104 		/// Number of HH Members 2-4 
		h11105 		/// Number of HH Members 5-7 
		h11106 		/// Number of HH Members 8-10 
		h11107 		/// Number of HH Members 11-12
		h11108 		/// Number of HH Members 13-15
		h11109 		/// Number of HH Members 16-18
		m11125 		/// Satisfaction with Health
		m11126 		/// Current Self-Rated Health
		p11101 		/// Overall Life Satisfaction 
		l11102		//  East/West
		
rename 		x11101ll	id 	
rename		d11102ll 	gender	
rename		x11104ll 	subsamp_gsoep
rename		x11102 		hhid	
rename		d11101 		age 
rename		d11104		marstat 
rename		d11105		relation
rename		d11106 		nhh	
rename		d11107 		nhhkid	
rename		d11109 		eduyrs 
rename		e11101 		wkhrs 
rename		e11102 		empstat
rename		i11101		grhhinc 
rename		i11102 		hhinc 
rename		i11110		lminc 
rename		w11101 		cwgt 
rename		w11102 		hhwgt 
rename		w11103		lwgt 
rename		h11103 		nhh_0_1 
rename		h11104 		nhh_2_4  
rename		h11105 		nhh_5_7 
rename		h11106 		nhh_8_10  
rename		h11107 		nhh_11_12 
rename		h11108 		nhh_13_15 
rename		h11109 		nhh_16_18 
rename		m11125 		sathealth 
rename		m11126 		srhealth 
rename		p11101 		lsat
rename 		l11102		region_gsoep

gen study = "Germany"

sort id year
save "$temp/gsoep.dta", replace

*-----------------------------------------------------------------------------*
*  GENERATE BHPS DATASET              		                                  *
*-----------------------------------------------------------------------------*

use "$cnef/bequiv_long.dta", clear

keep 	x11101LL 	///	Person ID
		year		///
		d11102LL 	/// Gender
		x11102 		/// Household ID
		x11104LL	/// Subsample Indicator
		d11112LL	/// Race
		d11101 		/// Age
		d11104		/// Marital Status
		d11105		/// Relationship to HH Head
		d11106 		/// Number of Persons in HH
		d11107 		/// Number of Children in HH
		e11101 		/// Annual Work Hours
		e11102 		/// Employment Status
		i11101 		/// HH Pre-Government Transfers
		i11102 		/// HH POst-Government Transfers
		i11110		/// Individual Labor Market Income
		w11101 		/// Cross-sectional Weight
		w11102 		/// HH Weight
		w11103		/// Longitudinal Weight
		h11103 		/// Number of HH Members 0-1 
		h11104 		/// Number of HH Members 2-4 
		h11105 		/// Number of HH Members 5-7 
		h11106 		/// Number of HH Members 8-10 
		h11107 		/// Number of HH Members 11-12
		h11108 		/// Number of HH Members 13-15
		h11109 		/// Number of HH Members 16-18
		m11125 		/// Satisfaction with Health
		m11126 		/// Current Self-Rated Health
		p11101 		/// Overall Life Satisfaction 
		l11102		//  Region
		
rename 		x11101LL	pid
merge 1:1 pid year using "$temp/BHPS_eduyrs.dta", ///
	keepusing(eduyrs) keep(1 3) nogen
		
rename 		pid			id 	
rename		d11102LL 	gender	
rename		x11104LL 	subsamp_bhps
rename		x11102 		hhid	
rename		d11101 		age 
rename		d11104		marstat  
rename		d11105		relation
rename		d11106 		nhh	
rename		d11107 		nhhkid	
rename		e11101 		wkhrs 
rename		e11102 		empstat 
rename		i11101		grhhinc 
rename		i11102 		hhinc 
rename		i11110		lminc 
rename		w11101 		cwgt 
rename		w11102 		hhwgt 
rename		w11103		lwgt 
rename		h11103 		nhh_0_1 
rename		h11104 		nhh_2_4  
rename		h11105 		nhh_5_7 
rename		h11106 		nhh_8_10  
rename		h11107 		nhh_11_12 
rename		h11108 		nhh_13_15 
rename		h11109 		nhh_16_18 
rename		m11125 		sathealth 
rename		m11126 		srhealth 
rename		p11101 		lsat
rename 		d11112LL	race_bhps
rename 		l11102		region_bhps

gen study = "Britain"

sort id year
save "$temp/bhps.dta", replace

*-----------------------------------------------------------------------------*
*  GENERATE HILDA DATASET              		                                  *
*-----------------------------------------------------------------------------*

use "$cnef/hequiv_long.dta", clear

keep 	xwaveid 	///	Person ID
		year		///
		d11102ll 	/// Gender
		x11102 		/// Household ID
		d11101 		/// Age
		d11104		/// Marital Status
		d11105		/// Relationship to HH Head
		d11106 		/// Number of Persons in HH
		d11107 		/// Number of Children in HH
		d11109 		/// Years of Education
		e11101 		/// Annual Work Hours
		e11102 		/// Employment Status
		i11101 		/// HH Pre-Government Transfers
		i11102 		/// HH POst-Government Transfers
		i11110		/// Individual Labor Market Income
		w11101 		/// Cross-sectional Weight
		w11102 		/// HH Weight
		w11103		/// Longitudinal Weight
		h11103 		/// Number of HH Members 0-1 
		h11104 		/// Number of HH Members 2-4 
		h11105 		/// Number of HH Members 5-7 
		h11106 		/// Number of HH Members 8-10 
		h11107 		/// Number of HH Members 11-12
		h11108 		/// Number of HH Members 13-15
		h11109 		/// Number of HH Members 16-18
		m11125 		/// Satisfaction with Health
		m11126 		/// Current Self-Rated Health
		p11101 		/// Overall Life Satisfaction 
		l11102		//  Region
		
encode xwaveid, gen(id)
cap drop xwaveid
rename		d11102ll 	gender	
rename		x11102 		hhid	
rename		d11101 		age 
rename		d11104		marstat 
rename		d11105		relation
rename		d11106 		nhh	
rename		d11107 		nhhkid	
rename		d11109 		eduyrs 
rename		e11101 		wkhrs 
rename		e11102 		empstat 
rename		i11101		grhhinc 
rename		i11102 		hhinc 
rename		i11110		lminc 
rename		w11101 		cwgt 
rename		w11102 		hhwgt 
rename		w11103		lwgt 
rename		h11103 		nhh_0_1 
rename		h11104 		nhh_2_4  
rename		h11105 		nhh_5_7 
rename		h11106 		nhh_8_10  
rename		h11107 		nhh_11_12 
rename		h11108 		nhh_13_15 
rename		h11109 		nhh_16_18 
rename		m11125 		sathealth 
rename		m11126 		srhealth 
rename		p11101 		lsat
rename 		l11102		region_hilda

gen study = "Australia"

sort id year
save "$temp/hilda.dta", replace

*-----------------------------------------------------------------------------*
*  GENERATE PSID DATASET              		                                  *
*-----------------------------------------------------------------------------*

use "$cnef/pequiv_long.dta", clear

replace i11102 = i11113 if i11102==.m & i11113!=.

keep 	x11101LL 	///	Person ID
		year		///
		d11102LL 	/// Gender
		x11102 		/// Household ID
		x11104LL	/// Subsample Indicator
		d11112LL	/// Race
		d11101 		/// Age
		d11104		/// Marital Status
		d11105		/// Relationship to HH Head
		d11106 		/// Number of Persons in HH
		d11107 		/// Number of Children in HH
		d11109 		/// Years of Education
		e11101 		/// Annual Work Hours
		e11102 		/// Employment Status
		i11101 		/// HH Pre-Government Transfers
		i11102 		/// HH POst-Government Transfers
		i11110		/// Individual Labor Market Income
		w11101 		/// Cross-sectional Weight
		w11102 		/// HH Weight
		w11103		/// Longitudinal Weight
		h11103 		/// Number of HH Members 0-1 
		h11104 		/// Number of HH Members 2-4 
		h11105 		/// Number of HH Members 5-7 
		h11106 		/// Number of HH Members 8-10 
		h11107 		/// Number of HH Members 11-12
		h11108 		/// Number of HH Members 13-15
		h11109 		/// Number of HH Members 16-18
		m11125 		/// Satisfaction with Health
		m11126 		/// Current Self-Rated Health
		p11101 		/// Overall Life Satisfaction 
		l11101		//  Region
		
rename 		x11101LL	id 	
rename		d11102LL 	gender	
rename		x11104LL 	subsamp_psid
rename		x11102 		hhid	
rename		d11101 		age 
rename		d11104		marstat 
rename		d11105		relation
rename		d11106 		nhh	
rename		d11107 		nhhkid	
rename		d11109 		eduyrs 
rename		e11101 		wkhrs 
rename		e11102 		empstat 
rename		i11101		grhhinc 
rename		i11102 		hhinc 
rename		i11110		lminc 
rename		w11101 		cwgt 
rename		w11102 		hhwgt 
rename		w11103		lwgt 
rename		h11103 		nhh_0_1 
rename		h11104 		nhh_2_4  
rename		h11105 		nhh_5_7 
rename		h11106 		nhh_8_10  
rename		h11107 		nhh_11_12 
rename		h11108 		nhh_13_15 
rename		h11109 		nhh_16_18 
rename		m11125 		sathealth 
rename		m11126 		srhealth 
rename		p11101 		lsat
rename 		d11112LL	race_psid
rename 		l11101		region_psid

gen study = "United States"

sort id year
save "$temp/psid.dta", replace

*-----------------------------------------------------------------------------*
*  GENERATE SHP DATASET              		                                  *
*-----------------------------------------------------------------------------*

use "$cnef/shpequiv_long.dta", clear

keep 	x11101LL 	///	Person ID
		year		///
		d11102LL 	/// Gender
		x11102 		/// Household ID
		x11104LL	/// Subsample Indicator
		d11101 		/// Age
		d11104		/// Marital Status
		d11105		/// Relationship to HH Head
		d11106 		/// Number of Persons in HH
		d11107 		/// Number of Children in HH
		d11109 		/// Years of Education
		e11101 		/// Annual Work Hours
		e11102 		/// Employment Status
		i11101 		/// HH Pre-Government Transfers
		i11102 		/// HH POst-Government Transfers
		i11110		/// Individual Labor Market Income
		w11101 		/// Cross-sectional Weight
		w11102 		/// HH Weight
		w11103		/// Longitudinal Weight
		h11103 		/// Number of HH Members 0-1 
		h11104 		/// Number of HH Members 2-4 
		h11105 		/// Number of HH Members 5-7 
		h11106 		/// Number of HH Members 8-10 
		h11107 		/// Number of HH Members 11-12
		h11108 		/// Number of HH Members 13-15
		h11109 		/// Number of HH Members 16-18
		m11125 		/// Satisfaction with Health
		m11126 		/// Current Self-Rated Health
		p11101 		/// Overall Life Satisfaction 
		l11101		//  Region
		
rename 		x11101LL	id 	
rename		d11102LL 	gender	
rename		x11104LL 	subsamp_shp
rename		x11102 		hhid	
rename		d11101 		age 
rename		d11104		marstat 
rename		d11105		relation
rename		d11106 		nhh	
rename		d11107 		nhhkid	
rename		d11109 		eduyrs 
rename		e11101 		wkhrs 
rename		e11102 		empstat 
rename		i11101		grhhinc 
rename		i11102 		hhinc 
rename		i11110		lminc 
rename		w11101 		cwgt 
rename		w11102 		hhwgt 
rename		w11103		lwgt 
rename		h11103 		nhh_0_1 
rename		h11104 		nhh_2_4  
rename		h11105 		nhh_5_7 
rename		h11106 		nhh_8_10  
rename		h11107 		nhh_11_12 
rename		h11108 		nhh_13_15 
rename		h11109 		nhh_16_18 
rename		m11125 		sathealth 
rename		m11126 		srhealth 
rename		p11101 		lsat
rename 		l11101		region_shp

gen study = "Switzerland"

sort id year
save "$temp/shp.dta", replace
