
log using "$logs/Divorce_CNEF.rtf", append text

*-----------------------------------------------------------------------------*
* Descriptive Graphs
*-----------------------------------------------------------------------------*

	use "$temp/cnef_analysis.dta" if study=="United States", clear
	sum year if marstat==4 & grnominc!=.
	drop if year<r(min)

tw 	lpolyci grnominc year if marstat==1 & nhhkid_red==0,							///
		lpattern(dot) lcolor(black%25) bwidth(2)								///
		ciplot(rline) clpattern(solid) clcolor(black%25)						///
	|| lpolyci grnominc year if marstat==4 & nhhkid_red==0,						///
		lpattern(dot) lcolor(sea%25) bwidth(2)									///
		ciplot(rline) clpattern(solid) clcolor(sea%25)							///
	|| lpolyci grnominc year if marstat==1 & nhhkid_red==1,						///
		lpattern(dot) lcolor(black%50) bwidth(2)								///
		ciplot(rline) clpattern(solid) clcolor(black%50)						///
	|| lpolyci grnominc year if marstat==4 & nhhkid_red==1,						///
		lpattern(dot) lcolor(sea%50) bwidth(2)									///
		ciplot(rline) clpattern(solid) clcolor(sea%50)							///		
	|| lpolyci grnominc year if marstat==1 & nhhkid_red==2,						///
		lpattern(dot) lcolor(black%75) bwidth(2)								///
		ciplot(rline) clpattern(solid) clcolor(black%75)						///
	|| lpolyci grnominc year if marstat==4 & nhhkid_red==2,						///
		lpattern(dot) lcolor(sea%75) bwidth(2)									///
		ciplot(rline) clpattern(solid) clcolor(sea%75)							///			
	|| lpolyci grnominc year if marstat==1 & nhhkid_red==3,						///
		lpattern(dot) lcolor(black%100) bwidth(2)								///
		ciplot(rline) clpattern(solid) clcolor(black%100)						///
	|| lpolyci grnominc year if marstat==4 & nhhkid_red==3,						///
		lpattern(dot) lcolor(sea%100) bwidth(2)									///
		ciplot(rline) clpattern(solid) clcolor(sea%100)							///		
	scheme(plotplainblind) legend(off)											///
	xtitle("Survey Year", size(small))											///
	ytitle("Gross Family Income", size(small))							///
	title("", size(small))														///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/des_grnominc.png", replace

*------------------------------------------------------------------------------*
* Descriptive Tables by Study & Family Size				                       *
*------------------------------------------------------------------------------*

replace age = age + 35

bysort id: gen n = _n

// Continous Age of Youngest Child for Descriptives //
replace kidage = .5 if kidage==1
replace kidage = 3 if kidage==2
replace kidage = 6 if kidage==3
replace kidage = 9 if kidage==4
replace kidage = 11.5 if kidage==5
replace kidage = 14 if kidage==6
replace kidage = 17 if kidage==7

*replace nominc = nominc/1000

forvalues k = 0/3 {

estpost																			///
tabstat	grnominc nhhkid eduyrs kidage mstat wkhrs age								///
	if sample==1 & nhhkid_red==`k'												///
	, stat(mean sd) col(stat)
est store D1

estpost																			///
tabstat																			///
		year_div 																///
		age_at		 															///
		birthy																	///
	if n== 1& sample==1 & nhhkid_red==`k'										///
	, stat(mean sd) col(stat)
est store D2

estpost																			///
tabstat	grnominc nhhkid eduyrs kidage mstat wkhrs age								///
	if sample==0 & nhhkid_red==`k'												///
	, stat(mean sd) col(stat)
est store C1

estpost																			///
tabstat			 																///
		birthy																	///
	if n==1 & sample==0 & nhhkid_red==`k'										///
	, stat(mean sd) col(stat)
est store C2

esttab D1 D2 C1 C2 using "$tables/des", 										///
	main(mean %8.2f) aux(sd %8.2f) label csv append nostar						///
	title("`x'") mtitles("Divoced (Person-Years)" "Divorced (Persons)" 			///
	"Control (Person-Years)" "Control (Persons)") nonumbers nonote 
}	

*------------------------------------------------------------------------------*
* Average of Variables of Divorce Sample across Duration by Family Size        *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States" 						///
	& sample==1 & index>=-1 & index<=6, clear

replace index = index + 1

// Continous Age of Youngest Child for Descriptives //
replace kidage = .5 if kidage==1
replace kidage = 3 if kidage==2
replace kidage = 6 if kidage==3
replace kidage = 9 if kidage==4
replace kidage = 11.5 if kidage==5
replace kidage = 14 if kidage==6
replace kidage = 17 if kidage==7

foreach y in grnominc nhhkid kidage mstat wkhrs {

local z: variable label `y'
	
reg `y' i.index##i.nhhkid_red
margins, over(index nhhkid_red)
marginsplot, scheme(plotplainblind)												///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xlabel(0 "-1" 1 "0" 2 "1" 3 "2" 4 "3" 5 "4" 6 "5" 7 "6")		///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 										///
	title("") xline(1, lcolor(reddish))											///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/des_`y'.png", replace

}

*------------------------------------------------------------------------------*
* Age Distribution of Divorce Sample across Duration by Family Size     	   *
*------------------------------------------------------------------------------*

replace age = age + 35

tw kdensity age, by(nhhkid_red, note("")) scheme(plotplainblind)				///
	xtitle("Age", size(small)) ytitle("Density", size(small)) 					///
	title("Family Size", size(small))
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kden_age.png", replace

*------------------------------------------------------------------------------*
* Sample Attrition across Duration by Family Size   					  	   *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States" 						///
	& sample==1 & index>=0 & index<=6, clear

egen aux = group(index nhhkid_red)
bys aux: gen n = _N

bys aux: drop if _n>1

gen n_max = n if index==0
bys nhhkid_red (index): replace n_max = n_max[_n-1] if index>0

gen pro_n = n/n_max	

tw scatter pro_n index if nhhkid_red==0, mcolor(black) msymbol(Oh)					///
		|| lpoly pro_n index if nhhkid_red==0, lcolor(black) lpattern(solid)		///
	|| scatter pro_n index if nhhkid_red==1, mcolor(ananas) msymbol(Oh)				///
		|| lpoly pro_n index if nhhkid_red==1, lcolor(ananas) lpattern(solid)		///
	|| scatter pro_n index if nhhkid_red==2, mcolor(orangebrown) msymbol(Oh)		///
		|| lpoly pro_n index if nhhkid_red==2, lcolor(orangebrown) lpattern(solid)	///
	|| scatter pro_n index if nhhkid_red==3, mcolor(vermillion) msymbol(Oh)			///
		|| lpoly pro_n index if nhhkid_red==3, lcolor(vermillion) lpattern(solid)	///
	, scheme(plotplainblind) xscale(range(0(1)6)) xlabel(0(1)6)						///
		xtitle("Years Following Divorce", size(small))								///
		ytitle("Proportion of Observations Retained", size(small))					///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))		
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/attrition.png", replace

log close
