
log using "$logs/Divorce_CNEF.rtf", append text

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* Unconditional Hybrid RE Models Net Family Income							   *
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta", clear

foreach y in lngrnominc {

local z: variable label `y'

use "$temp/cnef_analysis.dta" if study=="United States", clear
xtset id year

*------------------------------------------------------------------------------*
* Motherhood  															       *
*------------------------------------------------------------------------------*

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.mom																	///
		c.d_m#i.mom i.d#i.mom													///
		c.dur_m#i.mom c.dur#i.mom												///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/mom_unadj_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)												

*** Plot Predictions by Motherhood & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(mom) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(gs10)) 										///
	plot2opts(lpattern(solid) lcolor(gs10))										///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(3 "Childless" 4 "Mother") position(6) row(1))					///
	saving("$graphs/mom_`y'_p", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_p.png", replace
	
* Calculate & Plot Divorce Effect by Motherhood Status *
forvalues j = 0/1 {

	est restore mixed
	margins, dydx(d) at(dur=(0) mom=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed	
		margins, dydx(dur) at(d=(1) dur=(`m') mom=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
est restore mixed
margins, dydx(mom) at(d=(0) dur=(0) sample=(1)) post

	gen C_1 = _b[1.mom]
	gen CLB_1 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_1 = _b[1.mom] + _se[1.mom]*1.96

est restore mixed
margins, dydx(mom) at(d=(1) dur=(0) sample=(1)) post

	gen C_2 = _b[1.mom]
	gen CLB_2 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_2 = _b[1.mom] + _se[1.mom]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(mom) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C_`i' = _b[1.mom]
	gen CLB_`i' = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_`i' = _b[1.mom] + _se[1.mom]*1.96	
	
	local i = `i' + 1
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_ C_ CLB_ CUB_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB, i(T) j(mom)

bys mom (T): replace B = B[_n-1] + B if T>=1
bys mom (T): replace LB = LB[_n-1] + LB if T>=1
bys mom (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if mom==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if mom==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline LB UB T if mom==1, 												///
		lpattern(dot) lcolor(gs10)												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 				///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Childless" 3 "Mother") position(6) row(1))				///
		saving("$graphs/mom_`y'_c", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_c.png", replace

tw 	line C T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline CLB CUB T if mom==1, 												///
		lpattern(dot) lcolor(gs10) 												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Mother") position(6) row(1))															
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_d.png", replace
	
*------------------------------------------------------------------------------*
* Number of Children													       *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.nhhkid_red															///
		c.d_m#i.nhhkid_red i.d#i.nhhkid_red										///
		c.dur_m#i.nhhkid_red c.dur#i.nhhkid_red									///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/kid_unadj_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)
	
*** Plot Predictions by Family Size & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(nhhkid_red)  expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))				///
	saving("$graphs/kid_`y'_p", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_p.png", replace
	
*** Calculate & Plot Predictions by Family Size & Divorce Status ***
forvalues j = 0/3 {

	est restore mixed
	margins, dydx(d) at(dur=(0) nhhkid_red=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(d=(1) dur=(`m') nhhkid_red=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
forvalues j = 1/3 {

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(0) dur=(0) sample=(1)) post

	gen C`j'_1 = _b[`j'.nhhkid_red]
	gen CLB`j'_1 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_1 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(0) sample=(1)) post

	gen C`j'_2 = _b[`j'.nhhkid_red]
	gen CLB`j'_2 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_2 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C`j'_`i' = _b[`j'.nhhkid_red]
	gen CLB`j'_`i' = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_`i' = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96	
	
	local i = `i' + 1
}
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_										///
			 B2_ LB2_ UB2_ B3_ LB3_ UB3_										///
			 C1_ CLB1_ CUB1_ C2_ CLB2_ CUB2_									///
			 C3_ CLB3_ CUB3_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB C CLB CUB, i(T) j(kid)

bys kid (T): replace B = B[_n-1] + B if T>=1
bys kid (T): replace LB = LB[_n-1] + LB if T>=1
bys kid (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB  C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if kid==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if kid==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline LB UB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line B T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline LB UB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line B T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline LB UB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 				///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 									///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_c", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_c.png", replace

tw	 line C T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline CLB CUB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line C T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline CLB CUB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line C T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline CLB CUB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "1" 3 "2" 5 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_d", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_d.png", replace

use "$temp/cnef_analysis.dta", clear
}

log close
