
log using "$logs/Divorce_CNEF.rtf", append text

use "$temp/cnef_analysis.dta", clear

foreach y in lngrnominc {

local z: variable label `y'

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* Adjusted Hybrid RE Models on Poverty - Education							   *
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear
xtset id year

*------------------------------------------------------------------------------*
* Motherhood  															       *
*------------------------------------------------------------------------------*

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.mom																	///
		c.d_m#i.mom i.d#i.mom													///
		c.dur_m#i.mom c.dur#i.mom												///
	c.eduyrs																	///
	c.d_m#c.eduyrs i.d#c.eduyrs													///
	c.dur_m#c.eduyrs c.dur#c.eduyrs												///
		i.mom#c.eduyrs															///
		c.d_m#i.mom#c.eduyrs i.d#i.mom#c.eduyrs									///
		c.dur_m#i.mom#c.eduyrs c.dur#i.mom#c.eduyrs								///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/mom_eduyrs_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)												

*** Plot Predictions by Motherhood & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(mom) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(gs10)) 										///
	plot2opts(lpattern(solid) lcolor(gs10))										///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(3 "Childless" 4 "Mother") position(6) row(1))					///
	saving("$graphs/mom_`y'_p_eduyrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_p_eduyrs.png", replace
	
* Calculate & Plot Predictions by Motherhood & Divorce Status *

forvalues j = 0/1 {

	est restore mixed
	margins, dydx(d) at(dur=(0) mom=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed	
		margins, dydx(dur) at(d=(1) dur=(`m') mom=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
est restore mixed
margins, dydx(mom) at(d=(0) dur=(0) sample=(1)) post

	gen C_1 = _b[1.mom]
	gen CLB_1 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_1 = _b[1.mom] + _se[1.mom]*1.96

est restore mixed
margins, dydx(mom) at(d=(1) dur=(0) sample=(1)) post

	gen C_2 = _b[1.mom]
	gen CLB_2 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_2 = _b[1.mom] + _se[1.mom]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(mom) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C_`i' = _b[1.mom]
	gen CLB_`i' = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_`i' = _b[1.mom] + _se[1.mom]*1.96	
	
	local i = `i' + 1
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_ C_ CLB_ CUB_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB, i(T) j(mom)

bys mom (T): replace B = B[_n-1] + B if T>=1
bys mom (T): replace LB = LB[_n-1] + LB if T>=1
bys mom (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if mom==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if mom==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline LB UB T if mom==1, 												///
		lpattern(dot) lcolor(gs10)												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Childless" 3 "Mother") position(6) row(1))				///
		saving("$graphs/mom_`y'_c_eduyrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_c_eduyrs.png", replace

tw 	line C T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline CLB CUB T if mom==1, 												///
		lpattern(dot) lcolor(gs10) 												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Mother") position(6) row(1))							///
		saving("$graphs/mom_`y'_d_eduyrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_d_eduyrs.png", replace
	
*------------------------------------------------------------------------------*
* Number of Children													       *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.nhhkid_red															///
		c.d_m#i.nhhkid_red i.d#i.nhhkid_red										///
		c.dur_m#i.nhhkid_red c.dur#i.nhhkid_red									///
	c.eduyrs																	///
	c.d_m#c.eduyrs i.d#c.eduyrs													///
	c.dur_m#c.eduyrs c.dur#c.eduyrs												///
		i.nhhkid_red#c.eduyrs													///
		c.d_m#i.nhhkid_red#c.eduyrs i.d#i.nhhkid_red#c.eduyrs					///
		c.dur_m#i.nhhkid_red#c.eduyrs c.dur#i.nhhkid_red#c.eduyrs				///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed	
	
*** Regression Table ***
esttab using "$tables/kid_eduyrs_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)
	
*** Plot Predictions by Family Size & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(nhhkid_red) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))				///
	saving("$graphs/kid_`y'_p_eduyrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_p_eduyrs.png", replace
	
*** Calculate & Plot Predictions by Family Size & Divorce Status ***
forvalues j = 0/3 {

	est restore mixed
	margins, dydx(d) at(dur=(0) nhhkid_red=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(d=(1) dur=(`m') nhhkid_red=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
forvalues j = 1/3 {

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(0) dur=(0) sample=(1)) post

	gen C`j'_1 = _b[`j'.nhhkid_red]
	gen CLB`j'_1 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_1 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(0) sample=(1)) post

	gen C`j'_2 = _b[`j'.nhhkid_red]
	gen CLB`j'_2 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_2 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C`j'_`i' = _b[`j'.nhhkid_red]
	gen CLB`j'_`i' = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_`i' = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96	
	
	local i = `i' + 1
}
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_										///
			 B2_ LB2_ UB2_ B3_ LB3_ UB3_										///
			 C1_ CLB1_ CUB1_ C2_ CLB2_ CUB2_									///
			 C3_ CLB3_ CUB3_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB C CLB CUB, i(T) j(kid)

bys kid (T): replace B = B[_n-1] + B if T>=1
bys kid (T): replace LB = LB[_n-1] + LB if T>=1
bys kid (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB  C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if kid==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if kid==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline LB UB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line B T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline LB UB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line B T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline LB UB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 									///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_c_eduyrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_c_eduyrs.png", replace

tw	 line C T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline CLB CUB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line C T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline CLB CUB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line C T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline CLB CUB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "1" 3 "2" 5 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_d_eduyrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_d_eduyrs.png", replace

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* Adjusted Hybrid RE Models on Poverty - Age of Youngest Child				   *
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear
xtset id year

*------------------------------------------------------------------------------*
* Motherhood  															       *
*------------------------------------------------------------------------------*

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.mom																	///
		c.d_m#i.mom i.d#i.mom													///
		c.dur_m#i.mom c.dur#i.mom												///
	c.kidage																	///
	c.d_m#c.kidage i.d#c.kidage													///
	c.dur_m#c.kidage c.dur#c.kidage												///
		i.mom#c.kidage															///
		c.d_m#i.mom#c.kidage i.d#i.mom#c.kidage									///
		c.dur_m#i.mom#c.kidage c.dur#i.mom#c.kidage								///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/mom_kidage_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)												

*** Plot Predictions by Motherhood & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(mom) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(gs10)) 										///
	plot2opts(lpattern(solid) lcolor(gs10))										///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(3 "Childless" 4 "Mother") position(6) row(1))					///
	saving("$graphs/mom_`y'_p_kidage", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_p_kidage.png", replace
	
* Calculate & Plot Predictions by Motherhood & Divorce Status *

forvalues j = 0/1 {

	est restore mixed
	margins, dydx(d) at(dur=(0) mom=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed	
		margins, dydx(dur) at(d=(1) dur=(`m') mom=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}
* Calculate & Plot Motherhood Effect by Divorce Duration *
est restore mixed
margins, dydx(mom) at(d=(0) dur=(0) sample=(1)) post

	gen C_1 = _b[1.mom]
	gen CLB_1 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_1 = _b[1.mom] + _se[1.mom]*1.96

est restore mixed
margins, dydx(mom) at(d=(1) dur=(0) sample=(1)) post

	gen C_2 = _b[1.mom]
	gen CLB_2 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_2 = _b[1.mom] + _se[1.mom]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(mom) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C_`i' = _b[1.mom]
	gen CLB_`i' = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_`i' = _b[1.mom] + _se[1.mom]*1.96	
	
	local i = `i' + 1
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_ C_ CLB_ CUB_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB, i(T) j(mom)

bys mom (T): replace B = B[_n-1] + B if T>=1
bys mom (T): replace LB = LB[_n-1] + LB if T>=1
bys mom (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if mom==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if mom==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline LB UB T if mom==1, 												///
		lpattern(dot) lcolor(gs10)												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Childless" 3 "Mother") position(6) row(1))				///
		saving("$graphs/mom_`y'_c_kidage", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_c_kidage.png", replace

tw 	line C T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline CLB CUB T if mom==1, 												///
		lpattern(dot) lcolor(gs10) 												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Mother") position(6) row(1))							///
		saving("$graphs/mom_`y'_d_kidage", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_d_kidage.png", replace
	
*------------------------------------------------------------------------------*
* Number of Children													       *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.nhhkid_red															///
		c.d_m#i.nhhkid_red i.d#i.nhhkid_red										///
		c.dur_m#i.nhhkid_red c.dur#i.nhhkid_red									///
	c.kidage																	///
	c.d_m#c.kidage i.d#c.kidage													///
	c.dur_m#c.kidage c.dur#c.kidage												///
		i.nhhkid_red#c.kidage													///
		c.d_m#i.nhhkid_red#c.kidage i.d#i.nhhkid_red#c.kidage					///
		c.dur_m#i.nhhkid_red#c.kidage c.dur#i.nhhkid_red#c.kidage				///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/kid_kidage_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)
	
*** Plot Predictions by Family Size & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(nhhkid_red) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))				///
	saving("$graphs/kid_`y'_p_kidage", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_p_kidage.png", replace
	
*** Calculate & Plot Predictions by Family Size & Divorce Status ***
forvalues j = 0/3 {

	est restore mixed
	margins, dydx(d) at(dur=(0) nhhkid_red=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(d=(1) dur=(`m') nhhkid_red=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}
* Calculate & Plot Motherhood Effect by Divorce Duration *
forvalues j = 1/3 {

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(0) dur=(0) sample=(1)) post

	gen C`j'_1 = _b[`j'.nhhkid_red]
	gen CLB`j'_1 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_1 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(0) sample=(1)) post

	gen C`j'_2 = _b[`j'.nhhkid_red]
	gen CLB`j'_2 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_2 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C`j'_`i' = _b[`j'.nhhkid_red]
	gen CLB`j'_`i' = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_`i' = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96	
	
	local i = `i' + 1
}
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_										///
			 B2_ LB2_ UB2_ B3_ LB3_ UB3_										///
			 C1_ CLB1_ CUB1_ C2_ CLB2_ CUB2_									///
			 C3_ CLB3_ CUB3_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB C CLB CUB, i(T) j(kid)

bys kid (T): replace B = B[_n-1] + B if T>=1
bys kid (T): replace LB = LB[_n-1] + LB if T>=1
bys kid (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB  C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if kid==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if kid==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline LB UB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line B T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline LB UB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line B T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline LB UB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 									///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_c_kidage", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_c_kidage.png", replace

tw	 line C T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline CLB CUB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line C T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline CLB CUB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line C T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline CLB CUB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "1" 3 "2" 5 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_d_kidage", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_d_kidage.png", replace

use "$temp/cnef_analysis.dta", clear

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* Adjusted Hybrid RE Models on Poverty - Marital Status						   *
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear

*------------------------------------------------------------------------------*
* Motherhood  															       *
*------------------------------------------------------------------------------*

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.mom																	///
		c.d_m#i.mom i.d#i.mom													///
		c.dur_m#i.mom c.dur#i.mom												///
	i.mstat																		///
	c.d_m#i.mstat																///
	c.dur_m#i.mstat c.dur#i.mstat												///
		i.mom#i.mstat															///
		c.d_m#i.mom#i.mstat														///
		c.dur_m#i.mom#i.mstat c.dur#i.mom#i.mstat								///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/mom_mstat_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)												

*** Plot Predictions by Motherhood & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(mom) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(gs10)) 										///
	plot2opts(lpattern(solid) lcolor(gs10))										///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(3 "Childless" 4 "Mother") position(6) row(1))					///
	saving("$graphs/mom_`y'_p_mstat", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_p_mstat.png", replace
	
* Calculate & Plot Predictions by Motherhood & Divorce Status *

forvalues j = 0/1 {

	est restore mixed
	margins, dydx(d) at(dur=(0) mom=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(d=(1) dur=(`m') mom=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}
* Calculate & Plot Motherhood Effect by Divorce Duration *
est restore mixed
margins, dydx(mom) at(d=(0) dur=(0) sample=(1)) post

	gen C_1 = _b[1.mom]
	gen CLB_1 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_1 = _b[1.mom] + _se[1.mom]*1.96

est restore mixed
margins, dydx(mom) at(d=(1) dur=(0) sample=(1)) post

	gen C_2 = _b[1.mom]
	gen CLB_2 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_2 = _b[1.mom] + _se[1.mom]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(mom) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C_`i' = _b[1.mom]
	gen CLB_`i' = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_`i' = _b[1.mom] + _se[1.mom]*1.96	
	
	local i = `i' + 1
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_ C_ CLB_ CUB_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB, i(T) j(mom)

bys mom (T): replace B = B[_n-1] + B if T>=1
bys mom (T): replace LB = LB[_n-1] + LB if T>=1
bys mom (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if mom==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if mom==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline LB UB T if mom==1, 												///
		lpattern(dot) lcolor(gs10)												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Childless" 3 "Mother") position(6) row(1))				///
		saving("$graphs/mom_`y'_c_mstat", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_c_mstat.png", replace

tw 	line C T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline CLB CUB T if mom==1, 												///
		lpattern(dot) lcolor(gs10) 												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Mother") position(6) row(1))							///
		saving("$graphs/mom_`y'_d_mstat", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_d_mstat.png", replace
	
*------------------------------------------------------------------------------*
* Number of Children													       *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.nhhkid_red															///
		c.d_m#i.nhhkid_red i.d#i.nhhkid_red										///
		c.dur_m#i.nhhkid_red c.dur#i.nhhkid_red									///
	c.mstat																		///
	c.d_m#c.mstat																///
	c.dur_m#c.mstat c.dur#c.mstat												///
		i.nhhkid_red#c.mstat													///
		c.d_m#i.nhhkid_red#c.mstat												///
		c.dur_m#i.nhhkid_red#c.mstat c.dur#i.nhhkid_red#c.mstat					///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed	
	
*** Regression Table ***
esttab using "$tables/kid_mstat_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)
	
*** Plot Predictions by Family Size & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(nhhkid_red) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))				///
	saving("$graphs/kid_`y'_p_mstat", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_p_mstat.png", replace
	
*** Calculate & Plot Predictions by Family Size & Divorce Status ***
forvalues j = 0/3 {

	est restore mixed
	margins, dydx(d) at(dur=(0) nhhkid_red=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed	
		margins, dydx(dur) at(d=(1) dur=(`m') nhhkid_red=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}
* Calculate & Plot Motherhood Effect by Divorce Duration *
forvalues j = 1/3 {

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(0) dur=(0) sample=(1)) post

	gen C`j'_1 = _b[`j'.nhhkid_red]
	gen CLB`j'_1 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_1 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(0) sample=(1)) post

	gen C`j'_2 = _b[`j'.nhhkid_red]
	gen CLB`j'_2 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_2 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C`j'_`i' = _b[`j'.nhhkid_red]
	gen CLB`j'_`i' = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_`i' = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96	
	
	local i = `i' + 1
}
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_										///
			 B2_ LB2_ UB2_ B3_ LB3_ UB3_										///
			 C1_ CLB1_ CUB1_ C2_ CLB2_ CUB2_									///
			 C3_ CLB3_ CUB3_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB C CLB CUB, i(T) j(kid)

bys kid (T): replace B = B[_n-1] + B if T>=1
bys kid (T): replace LB = LB[_n-1] + LB if T>=1
bys kid (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB  C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if kid==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if kid==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline LB UB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line B T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline LB UB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line B T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline LB UB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 									///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_c_mstat", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_c_mstat.png", replace

tw	 line C T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline CLB CUB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line C T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline CLB CUB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line C T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline CLB CUB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "1" 3 "2" 5 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_d_mstat", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_d_mstat.png", replace

use "$temp/cnef_analysis.dta", clear

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* Adjusted Hybrid RE Models on Poverty - Number of Children					   *
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear
xtset id year

*------------------------------------------------------------------------------*
* Motherhood  															       *
*------------------------------------------------------------------------------*

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.mom																	///
		c.d_m#i.mom i.d#i.mom													///
		c.dur_m#i.mom c.dur#i.mom												///
	c.nhhkid																	///
	c.d_m#c.nhhkid i.d#c.nhhkid													///
	c.dur_m#c.nhhkid c.dur#c.nhhkid												///
		i.mom#c.nhhkid															///
		c.d_m#i.mom#c.nhhkid i.d#i.mom#c.nhhkid									///
		c.dur_m#i.mom#c.nhhkid c.dur#i.mom#c.nhhkid								///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/mom_nhhkid_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)												

*** Plot Predictions by Motherhood & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(mom) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(gs10)) 										///
	plot2opts(lpattern(solid) lcolor(gs10))										///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(3 "Childless" 4 "Mother") position(6) row(1))					///
	saving("$graphs/mom_`y'_p_nhhkid", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_p_nhhkid.png", replace
	
* Calculate & Plot Predictions by Motherhood & Divorce Status *

forvalues j = 0/1 {

	est restore mixed
	margins, dydx(d) at(dur=(0) mom=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(d=(1) dur=(`m') mom=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}
* Calculate & Plot Motherhood Effect by Divorce Duration *
est restore mixed
margins, dydx(mom) at(d=(0) dur=(0) sample=(1)) post

	gen C_1 = _b[1.mom]
	gen CLB_1 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_1 = _b[1.mom] + _se[1.mom]*1.96

est restore mixed
margins, dydx(mom) at(d=(1) dur=(0) sample=(1)) post

	gen C_2 = _b[1.mom]
	gen CLB_2 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_2 = _b[1.mom] + _se[1.mom]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(mom) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C_`i' = _b[1.mom]
	gen CLB_`i' = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_`i' = _b[1.mom] + _se[1.mom]*1.96	
	
	local i = `i' + 1
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_ C_ CLB_ CUB_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB, i(T) j(mom)

bys mom (T): replace B = B[_n-1] + B if T>=1
bys mom (T): replace LB = LB[_n-1] + LB if T>=1
bys mom (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if mom==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if mom==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline LB UB T if mom==1, 												///
		lpattern(dot) lcolor(gs10)												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Childless" 3 "Mother") position(6) row(1))				///
		saving("$graphs/mom_`y'_c_nhhkid", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_c_nhhkid.png", replace

tw 	line C T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline CLB CUB T if mom==1, 												///
		lpattern(dot) lcolor(gs10) 												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Mother") position(6) row(1))							///
		saving("$graphs/mom_`y'_d_nhhkid", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_d_nhhkid.png", replace
	
*------------------------------------------------------------------------------*
* Number of Children													       *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.nhhkid_red															///
		c.d_m#i.nhhkid_red i.d#i.nhhkid_red										///
		c.dur_m#i.nhhkid_red c.dur#i.nhhkid_red									///
	c.nhhkid																	///
	c.d_m#c.nhhkid i.d#c.nhhkid													///
	c.dur_m#c.nhhkid c.dur#c.nhhkid												///
		i.nhhkid_red#c.nhhkid													///
		c.d_m#i.nhhkid_red#c.nhhkid i.d#i.nhhkid_red#c.nhhkid					///
		c.dur_m#i.nhhkid_red#c.nhhkid c.dur#i.nhhkid_red#c.nhhkid				///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed	
	
*** Regression Table ***
esttab using "$tables/kid_nhhkid_`z'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)
	
*** Plot Predictions by Family Size & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(nhhkid_red) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))				///
	saving("$graphs/kid_`y'_p_nhhkid", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_p_nhhkid.png", replace
	
*** Calculate & Plot Predictions by Family Size & Divorce Status ***
forvalues j = 0/3 {

	est restore mixed
	margins, dydx(d) at(dur=(0) nhhkid_red=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(d=(1) dur=(`m') nhhkid_red=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
forvalues j = 1/3 {

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(0) dur=(0) sample=(1)) post

	gen C`j'_1 = _b[`j'.nhhkid_red]
	gen CLB`j'_1 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_1 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(0) sample=(1)) post

	gen C`j'_2 = _b[`j'.nhhkid_red]
	gen CLB`j'_2 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_2 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C`j'_`i' = _b[`j'.nhhkid_red]
	gen CLB`j'_`i' = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_`i' = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96	
	
	local i = `i' + 1
}
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_										///
			 B2_ LB2_ UB2_ B3_ LB3_ UB3_										///
			 C1_ CLB1_ CUB1_ C2_ CLB2_ CUB2_									///
			 C3_ CLB3_ CUB3_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB C CLB CUB, i(T) j(kid)

bys kid (T): replace B = B[_n-1] + B if T>=1
bys kid (T): replace LB = LB[_n-1] + LB if T>=1
bys kid (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB  C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if kid==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if kid==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline LB UB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line B T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline LB UB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line B T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline LB UB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 									///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_c_nhhkid", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_c_nhhkid.png", replace

tw	 line C T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline CLB CUB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line C T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline CLB CUB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line C T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline CLB CUB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "1" 3 "2" 5 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_d_nhhkid", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_d_nhhkid.png", replace

use "$temp/cnef_analysis.dta", clear

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* Adjusted Hybrid RE Models on Poverty - Working Hours						   *
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear
xtset id year

*------------------------------------------------------------------------------*
* Motherhood  															       *
*------------------------------------------------------------------------------*

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.mom																	///
		c.d_m#i.mom i.d#i.mom													///
		c.dur_m#i.mom c.dur#i.mom												///
	c.wkhrs																		///
	c.d_m#c.wkhrs i.d#c.wkhrs													///
	c.dur_m#c.wkhrs c.dur#c.wkhrs												///
		i.mom#c.wkhrs															///
		c.d_m#i.mom#c.wkhrs i.d#i.mom#c.wkhrs									///
		c.dur_m#i.mom#c.wkhrs c.dur#i.mom#c.wkhrs								///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed
	
*** Regression Table ***
esttab using "$tables/mom_wkhrs_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)												

*** Plot Predictions by Motherhood & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(mom) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(gs10)) 										///
	plot2opts(lpattern(solid) lcolor(gs10))										///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(3 "Childless" 4 "Mother") position(6) row(1))					///
	saving("$graphs/mom_`y'_p_wkhrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_p_wkhrs.png", replace
	
* Calculate & Plot Predictions by Motherhood & Divorce Status *

forvalues j = 0/1 {

	est restore mixed
	margins, dydx(d) at(dur=(0) mom=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed		
		margins, dydx(dur) at(d=(1) dur=(`m') mom=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
est restore mixed
margins, dydx(mom) at(d=(0) dur=(0) sample=(1)) post

	gen C_1 = _b[1.mom]
	gen CLB_1 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_1 = _b[1.mom] + _se[1.mom]*1.96

est restore mixed
margins, dydx(mom) at(d=(1) dur=(0) sample=(1)) post

	gen C_2 = _b[1.mom]
	gen CLB_2 = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_2 = _b[1.mom] + _se[1.mom]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(mom) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C_`i' = _b[1.mom]
	gen CLB_`i' = _b[1.mom] - _se[1.mom]*1.96
	gen CUB_`i' = _b[1.mom] + _se[1.mom]*1.96	
	
	local i = `i' + 1
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_ C_ CLB_ CUB_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB, i(T) j(mom)

bys mom (T): replace B = B[_n-1] + B if T>=1
bys mom (T): replace LB = LB[_n-1] + LB if T>=1
bys mom (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if mom==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if mom==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline LB UB T if mom==1, 												///
		lpattern(dot) lcolor(gs10)												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Childless" 3 "Mother") position(6) row(1))				///
		saving("$graphs/mom_`y'_c_wkhrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_c_wkhrs.png", replace

tw 	line C T if mom==1, 														///
		lpattern(solid) lcolor(gs10) 											///
	|| rline CLB CUB T if mom==1, 												///
		lpattern(dot) lcolor(gs10) 												///
	scheme(plotplainblind) 														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "Mother") position(6) row(1))							///
		saving("$graphs/mom_`y'_d_wkhrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/mom_`y'_d_wkhrs.png", replace
	
*------------------------------------------------------------------------------*
* Number of Children													       *
*------------------------------------------------------------------------------*

use "$temp/cnef_analysis.dta" if study=="United States", clear

mixed `y'																		///
	c.d_m i.d																	///
	c.dur_m c.dur																///
		i.nhhkid_red															///
		c.d_m#i.nhhkid_red i.d#i.nhhkid_red										///
		c.dur_m#i.nhhkid_red c.dur#i.nhhkid_red									///
	c.wkhrs																		///
	c.d_m#c.wkhrs i.d#c.wkhrs													///
	c.dur_m#c.wkhrs c.dur#c.wkhrs												///
		i.nhhkid_red#c.wkhrs													///
		c.d_m#i.nhhkid_red#c.wkhrs i.d#i.nhhkid_red#c.wkhrs						///
		c.dur_m#i.nhhkid_red#c.wkhrs c.dur#i.nhhkid_red#c.wkhrs					///
			i.sample															///
				c.age_m c.age_d													///
				c.age_m#c.age_m c.age_d#c.age_d									///
					yr_m 														///	
						|| id: , mle
						 
est store mixed	
	
*** Regression Table ***
esttab using "$tables/kid_wkhrs_`y'", 											///
	b(%8.3f) se(%8.3f) mtitle("`x'") csv append									///
	scalars(r2_o N_g N) sfmt(%8.3f %8.0f %8.0f)	obslast							///
	star(+ 0.05 * 0.01 ** 0.001)
	
*** Plot Predictions by Family Size & Divorce Status ***
est restore mixed
margins,																		///
		at(d=(0) dur=(-1) sample=(1))											///
		at(d=(1) dur=(0) sample=(1)) 											///
		at(d=(1) dur=(1 2 3 4 5 6) sample=(1)) 									///
		over(nhhkid_red) expression(exp(predict(xb)))		
marginsplot, scheme(plotplainblind) 											///
	recast(line) recastci(rline) 												///
	ci1opts(lpattern(dot) lcolor(black)) 										///
	plot1opts(lpattern(solid) lcolor(black))									///
	ci2opts(lpattern(dot) lcolor(ananas)) 										///
	plot2opts(lpattern(solid) lcolor(ananas))									///
	ci3opts(lpattern(dot) lcolor(orangebrown)) 									///
	plot3opts(lpattern(solid) lcolor(orangebrown))								///
	ci4opts(lpattern(dot) lcolor(vermillion)) 									///
	plot4opts(lpattern(solid) lcolor(vermillion))								///
	xtitle("Years Following Divorce", size(small)) 								///
	ytitle("`z'", size(small)) 													///
	title("")																	///
	xlabel(, glcolor(gs13)) ylabel(, glcolor(gs13))								///
	legend(order(5 "0" 6 "1" 7 "2" 8 "3+") 										///
	title("Number of Children", size(small)) position(6) row(1))				///
	saving("$graphs/kid_`y'_p_wkhrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_p_wkhrs.png", replace
	
*** Calculate & Plot Predictions by Family Size & Divorce Status ***
forvalues j = 0/3 {

	est restore mixed
	margins, dydx(d) at(dur=(0) nhhkid_red=(`j') sample=(1)) post	
		gen B`j'_1 = _b[0b.d]
		gen LB`j'_1 = _b[0b.d] - 1.96*_se[0b.d]
		gen UB`j'_1 = _b[0b.d] + 1.96*_se[0b.d]
		gen B`j'_2 = _b[1.d]
		gen LB`j'_2 = _b[1.d] - 1.96*_se[1.d]
		gen UB`j'_2 = _b[1.d] + 1.96*_se[1.d]
		
	local i = 3
	forvalues m = 1/6 {
		est restore mixed	
		margins, dydx(dur) at(d=(1) dur=(`m') nhhkid_red=(`j') sample=(1)) post						
			gen B`j'_`i' = _b[dur]
			gen LB`j'_`i' = _b[dur] - 1.96*_se[dur]
			gen UB`j'_`i' = _b[dur] + 1.96*_se[dur]
			local i = `i' + 1
	}
}

* Calculate & Plot Motherhood Effect by Divorce Duration *
forvalues j = 1/3 {

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(0) dur=(0) sample=(1)) post

	gen C`j'_1 = _b[`j'.nhhkid_red]
	gen CLB`j'_1 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_1 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

est restore mixed
margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(0) sample=(1)) post

	gen C`j'_2 = _b[`j'.nhhkid_red]
	gen CLB`j'_2 = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_2 = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96

local i = 3
forvalues m = 1/6	{

	est restore mixed
	margins, dydx(`j'.nhhkid_red) at(d=(1) dur=(`m') sample=(1)) post
	
	gen C`j'_`i' = _b[`j'.nhhkid_red]
	gen CLB`j'_`i' = _b[`j'.nhhkid_red] - _se[`j'.nhhkid_red]*1.96
	gen CUB`j'_`i' = _b[`j'.nhhkid_red] + _se[`j'.nhhkid_red]*1.96	
	
	local i = `i' + 1
}
}

* Reshape Data for Graphs
keep B* LB* UB* C* CLB* CUB*
cap drop birthy
drop if _n>1
gen id = 1	
	
reshape long B0_ LB0_ UB0_ B1_ LB1_ UB1_										///
			 B2_ LB2_ UB2_ B3_ LB3_ UB3_										///
			 C1_ CLB1_ CUB1_ C2_ CLB2_ CUB2_									///
			 C3_ CLB3_ CUB3_, i(id) j(T)
replace T = T - 2
rename *_ *
cap drop id

reshape long B LB UB C CLB CUB, i(T) j(kid)

bys kid (T): replace B = B[_n-1] + B if T>=1
bys kid (T): replace LB = LB[_n-1] + LB if T>=1
bys kid (T): replace UB = UB[_n-1] + UB if T>=1

foreach x of varlist B LB UB  C CLB CUB {

	replace `x' = (exp(`x') - 1)*100
}

* Coefficient Plot *
tw 	line B T if kid==0, 														///
		lpattern(solid) lcolor(black) 											///
	|| rline LB UB T if kid==0, 												///
		lpattern(dot) lcolor(black) 											///
	|| line B T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline LB UB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line B T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline LB UB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line B T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline LB UB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Change in `z' (%)", size(small)) 								///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "0" 3 "1" 5 "2" 7 "3+") 									///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_c_wkhrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_c_wkhrs.png", replace

tw	 line C T if kid==1, 														///
		lpattern(solid) lcolor(ananas) 											///
	|| rline CLB CUB T if kid==1, 												///
		lpattern(dot) lcolor(ananas)											///
	|| line C T if kid==2, 														///
		lpattern(solid) lcolor(orangebrown) 									///
	|| rline CLB CUB T if kid==2, 												///
		lpattern(dot) lcolor(orangebrown) 										///
	|| line C T if kid==3, 														///
		lpattern(solid) lcolor(vermillion) 										///
	|| rline CLB CUB T if kid==3, 												///
		lpattern(dot) lcolor(vermillion)										///
	scheme(plotplainblind)														///
		yline(0, lcolor(reddish))												///
		ytitle("Difference in `z' (%)" "(ref. Childless Women)", size(small)) 	///
		xtitle("Years Following Divorce", size(small))							///
		xscale(range(-1(1)6)) xlabel(-1(1)6)									///
		title("") 																///
		legend(order(1 "1" 3 "2" 5 "3+") 										///
		title("Number of Children", size(small)) position(6) row(1))			///
		saving("$graphs/kid_`y'_d_wkhrs", replace)
gr display , xsize(11.7) ysize(8.3)
gr export "$graphs/kid_`y'_d_wkhrs.png", replace

use "$temp/cnef_analysis.dta", clear

}

log close
